#
# spec file for package python-virtualenv-clone
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-virtualenv-clone
Version:        0.5.7
Release:        1.6
Summary:        Script to clone virtualenvs
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/edwardgeorge/virtualenv-clone
Source:         https://files.pythonhosted.org/packages/source/v/virtualenv-clone/virtualenv-clone-%{version}.tar.gz
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module virtualenv}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-virtualenv
Requires(post): update-alternatives
Requires(preun):update-alternatives
BuildArch:      noarch
%python_subpackages

%description
virtualenv cloning script.

A script for cloning a non-relocatable virtualenv.

Virtualenv provides a way to make virtualenv's relocatable which could then be
copied as we wanted. However making a virtualenv relocatable this way breaks
the no-site-packages isolation of the virtualenv as well as other aspects that
come with relative paths and '%{_bindir}/env' shebangs that may be undesirable.

Also, the .pth and .egg-link rewriting doesn't seem to work as intended. This
attempts to overcome these issues and provide a way to easily clone an
existing virtualenv.

It performs the following:

- copies sys.argv[1] dir to sys.argv[2]
- updates the hardcoded VIRTUAL_ENV variable in the activate script to the
  new repo location. (--relocatable doesn't touch this)
- updates the shebangs of the various scripts in bin to the new python if
  they pointed to the old python. (version numbering is retained.)

    it can also change '%{_bindir}/env python' shebangs to be absolute too,
    though this functionality is not exposed at present.

- checks sys.path of the cloned virtualenv and if any of the paths are from
  the old environment it finds any .pth or .egg-link files within sys.path
  located in the new environment and makes sure any absolute paths to the
  old environment are updated to the new environment.

- finally it double checks sys.path again and will fail if there are still
  paths from the old environment present.

%prep
%setup -q -n virtualenv-clone-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# setup up update-alternatives
%python_clone -a %{buildroot}%{_bindir}/virtualenv-clone

%check
# The tests are not shipped and there are no tags in git repo :/
#%%pytest

%post
%python_install_alternative virtualenv-clone

%preun
%python_uninstall_alternative virtualenv-clone

%files %{python_files}
%license LICENSE
%doc README.md
%python_alternative %{_bindir}/virtualenv-clone
%{python_sitelib}/*

%changelog
* Wed Oct 12 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.5.7
  * Added tox.ini to source distributions.
- Update to version 0.5.6
  * Added support for Python 3.10.
- Update to version 0.5.5
  * Added support for Python 3.9.
* Thu Apr 16 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.5.4:
  * Added support for Python 3.8.
* Fri Apr 12 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.5.3
  0.5.?
  * Fixed incorrect Python version value.
  * Added support for Python 3.7.
  0.4.0
  * Dropped support for EOL Python versions that no longer
    receive any updates from the core CPython team.
  0.3.0
  * Added support for Python 3.
  * Fixed a bug with writing unicode in .pth files incorrectly.
  * Fixed support for paths involving symbolic links.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Apr 19 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Mon Feb 29 2016 someuniquename@gmail.com
- Update to version 2.6
  * Fix symlinks that point to the old virtual env
* Tue Dec  9 2014 toddrme2178@gmail.com
- Fix update-alternatives as requested.
* Mon Dec  1 2014 toddrme2178@gmail.com
- Update to 2.5
  * Speed clone_virtualenv up slightly by removing duplicate calls
    to spawn process
  * Improve windows compatibility
  * Ship LICENSE along with the source distribution to pypi.
  * Added verbose mode with logging.
  * Bugfixes
- Implement update alternatives to allow co-install with python 3
  version.
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Thu Aug  2 2012 alexandre@exatati.com.br
- Initial package (0.2.4) for openSUSE.
